@@ -3,11 +3,8 @@ from .checkpointer import Checkpointer
 from .statistics import PerfLogger, PerfLoggerConfig, Statistic
 from .remotesync import get_remote_config, _RemoteSyncrhoniser
 
-from ..modules import ExperimentInitConfig
-
 
 def get_metadata_manager(
-    exp_config: ExperimentInitConfig,
     log_config: PerfLoggerConfig,
     remote_sync: _RemoteSyncrhoniser | None = None,
     **checkpointables,
