@@ -2,13 +2,30 @@
 Statistic which contains a simple dictionary of scalars.
 This is particularly useful for tracking a bunch of scalars such as losses.
 """
-from typing import Dict, List
+from dataclasses import dataclass
+from typing import Any, Dict, List
 
 import numpy as np
 
+try:
+    import torch
+except ImportError:
+
+    def _scalar_checker(data: Any) -> int | float:
+        return data
+
+else:
+
+    def _scalar_checker(data: Any) -> int | float:
+        if isinstance(data, torch.Tensor):
+            return data.item()
+        return data
+
+
 from .statistic import Statistic, STATISTICS_REGISTRY
 
 
+@dataclass
 @STATISTICS_REGISTRY.register_module("Scalars")
 class ScalarStatistic(Statistic):
     """
@@ -16,6 +33,9 @@ class ScalarStatistic(Statistic):
     are automatically added to the class.
     """
 
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     def _register_statistics(self, keys: List[str]) -> None:
         """Add each of the keys to the tracked statistics"""
         logstr = "Registering: "
@@ -35,4 +55,4 @@ class ScalarStatistic(Statistic):
 
         super().__call__(it)
         for name, value in data.items():
-            self._append_sample(name, value)
+            self._append_sample(name, _scalar_checker(value))
