@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 import os
 from typing import Any
 
@@ -6,10 +7,14 @@ from .. import Mode, DatasetConfig, DATASET_REGISTRY
 from torchvision.datasets import MNIST
 
 
-@DATASET_REGISTRY.register_module()
+@dataclass
+@DATASET_REGISTRY.register_module("MNIST")
 class MNISTConfig(DatasetConfig):
     """Wrapper to use torchvision dataset"""
 
     def get_instance(self, mode: Mode) -> Any:
-        MNIST(os.environ.get("DATA_ROOT", "/data"), train=mode == Mode.train)
-        return super().get_instance(mode)
+        return MNIST(
+            os.environ.get("DATA_ROOT", "/data"),
+            train=mode == Mode.train,
+            download=True,
+        )
