@@ -1,3 +1,5 @@
+from dataclasses import dataclass
+
 import torch
 from nvidia.dali.plugin.pytorch import DALIGenericIterator
 
@@ -5,13 +7,14 @@ from . import DataloaderConfig, DATALOADER_REGISTRY, Mode
 from ...utilities.comm import get_rank, get_world_size
 
 
+@dataclass
 @DATALOADER_REGISTRY.register_module("DALI")
 class DaliLoaderConfig(DataloaderConfig):
     def get_instance(self, *args):
         pipe_kwargs = {
             "shard_id": get_rank(),
             "num_shards": get_world_size(),
-            "num_threads": self.workers,
+            "num_threads": max(self.workers, 1),
             "device_id": torch.cuda.current_device(),
             "batch_size": self.batch_size // get_world_size(),
         }
