@@ -1,5 +1,5 @@
 from torch import nn
-from .pytorch import PyTorchTrainer, PytorchTrainingModules
+from .pytorch import PyTorchTrainer, PyTorchTrainerModules
 
 
 def get_model_from_experiment() -> nn.Module:
